==> h5p-7.x-1.43.tar.gz: h5p/modules/h5peditor/h5peditor/language/ar.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'جاري التحميل الرجاءالانتظار...',
  selectLibrary: 'حدد المكتبة التي ترغب في استخدامها للمحتوى الخاص بك.',
  unknownFieldPath: 'تعذر العثور على ":path".',
  notImageField: '":path" ليست صورة.',
  notImageOrDimensionsField: '":path" ليست صورة أو أبعاد حقل',
  requiredProperty: 'ال :property مطلوب ويجب أن يكون له قيمة.',
  onlyNumbers: ' :property القيمة يمكن أن تحوي على أرقام فقط.',
  exceedsMax: ' :property القيمة تتجاوز الحد الأعظمي لـ :max.',
  listExceedsMax: 'تتجاوز القائمة الحد الأقصى لـ :max items.',
  belowMin: ' :property القيمة تحت الحد الأدنى من  :min.',
  listBelowMin: 'القائمة تحتاج على الأقل :min العناصر للمحتوى لتعمل بشكل صحيح',
  outOfStep: ' :property يمكن تغيير قيمة فقط في خطوات من :step.',
  add: 'اضافة',
  addFile: 'اضافة ملف',
  removeFile: 'حذف ملف',
  confirmRemoval: 'هل أنت متأكد أنك تريد حذف :type?',
  removeImage: 'حذف الصورة',
  confirmImageRemoval: 'سيؤدي هذا إلى إزالة الصورة. هل أنت متأكد أنك تريد المتابعة?',
  changeFile: 'تغيير الملف',
  changeLibrary: 'تغيير نوع المحتوى?',
  semanticsError: 'خطأ في الدلالات: :error',
  missingProperty: 'الحقل :index مفقود :property خصائصه.',
  expandCollapse: 'توسيع/طي',
  addEntity: 'اذافة :entity',
  tooLong: 'قيمة الحقل طويلة جداً يجب أن تتضمن :max من الحروف والأرقام',
  invalidFormat: 'تحتوي قيمة الحقل على تنسيق غير صالح أو أحرف غير مسموح بها.',
  confirmChangeLibrary: 'من خلال القيام بذلك سوف تفقد كل العمل المنجز مع نوع المحتوى الحالي. هل تريد بالتأكيد تغيير نوع المحتوى؟',
  commonFields: 'تجاوزات النصوص والترجمة',
  commonFieldsDescription: 'يمكنك هنا تعديل الإعدادات أو ترجمة النصوص المستخدمة في هذا المحتوى.',
  uploading: 'جاري التحميل .. الرجاء الانتظار...',
  noFollow: 'لا يمكن متابعة الحقل ":path".',
  editCopyright: 'تعديل حقوق الطبع والنشر',
  close: 'اغلاق',
  tutorial: 'تعليم',
  editMode: 'نمط التحرير',
  listLabel: 'قائمة',
  uploadError: 'خطأ في تحميل الملف',
  fileToLarge: 'قد يكون الملف الذي تحاول تحميله كبيرا جدا.',
  unknownFileUploadError: 'خطأ في تحميل الملف غير معروف',
  noSemantics: 'حدث خطأ، تعذر تحميل نموذج نوع المحتوى.',
  editImage: 'تعديل الصورة',
  saveLabel: 'حفظ',
  cancelLabel: 'إلغاء',
  resetToOriginalLabel: 'إعادة التعيين إلى النسخة الأصلية',
  loadingImageEditor: 'تحميل محرر الصور، يرجى الانتظار...',
  selectFiletoUpload: 'حدد ملفا لتحميله',
  or: 'أو',
  enterAudioUrl: 'أدخل عنوان مصدر الصوت',
  enterVideoUrl: 'أدخل عنوان مصدر الفيديو أو رابط اليوتيوب',
  enterAudioTitle: 'الصق الرابط أو عنوان مصدر الصوت الاخر',
  enterVideoTitle: 'ألصق رابط اليوتيوب أو عنوان مصدر الفيديو الاخر',
  uploadAudioTitle: 'رفع ملف الصوت',
  uploadVideoTitle: 'رفع ملف الفيديو',
  addVideoDescription: 'النظام يدعم جميع مصادر الفيديو الخارجية بتنسيق MP4 ,webm or ogv ويدعم روابط يوتيوب',
  insert: 'ادراج',
  cancel: 'الغاء',
  height: 'ارتفاع',
  width: 'عرض',
  textField: 'حقل نصي',
  numberField: 'حقل رقمي',
  orderItemUp: 'ترتيب العنصر لأعلى',
  orderItemDown: 'ترتيب العنصر لأدنى',
  removeItem: 'إزالة العنصر',
  hubPanelLabel: 'اختر نوع المحتوى',
  importantInstructions: 'تعليمات هامة',
  showImportantInstructions: 'Show instructions',
  hideImportantInstructions: 'إخفاء التعليمات الهامة',
  hide: 'إخفاء',
  example: 'مثال',
  createContentTabLabel: 'إنشاء محتوى',
  uploadTabLabel: 'رفع',
  uploadPlaceholder: 'لم يتم اختيار ملف',
  uploadInstructionsTitle: 'رفع ملف',
  uploadInstructionsContent: 'يمكن أن تجد أمثلة في <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'رفع ملف',
  uploadFileButtonChangeLabel: 'تغيير الملف',
  uploadingThrobber: 'يتم الرفع الان...',
  uploadSuccess: ':title was successfully uploaded!',
  unableToInterpretError: 'Unable to interpret response.',
  unableToInterpretSolution: 'Please check your error log.',
  h5pFileWrongExtensionTitle: 'تعذر تحميل الملف المحدد',
  h5pFileWrongExtensionContent: 'فقط الملفات بالامتداد .h5p مسموحة.',
  h5pFileValidationFailedTitle: 'تعذر التحقق من الملف.',
  h5pFileValidationFailedContent: 'تأكد أن الملف الذي تم رفعه يحوي على محتوى صالح. H5P يجب تحميل الملفات التي تحتوي على مكتبات فقط من خلال صفحة مكتبات H5P.',
  h5pFileUploadServerErrorTitle: 'الملف لا يمكن تحميله',
  h5pFileUploadServerErrorContent: 'حدث خطأ غير متوقع. تحقق من سجل أخطاء السيرفر  more details.',
  contentTypeSectionAll: 'الكل',
  searchResults: 'Search Results',
  contentTypeSearchFieldPlaceholder: 'البحث عن أنواع المحتوى',
  contentTypeInstallButtonLabel: 'تحميل',
  contentTypeInstallingButtonLabel: 'تحميل',
  contentTypeUseButtonLabel: 'استخدم',
  contentTypeDetailButtonLabel: 'Details',
  contentTypeUpdateButtonLabel: 'تحديث',
  contentTypeUpdatingButtonLabel: 'تحديث',
  contentTypeGetButtonLabel: 'احصل على',
  contentTypeBackButtonLabel: 'العودة',
  contentTypeIconAltText: 'أيقونة',
  contentTypeInstallSuccess: ':contentType تم تحميلها بنجاح!',
  contentTypeUpdateSuccess: ':contentType تم التحديث بنجاح!',
  contentTypeInstallError: ':contentType لا يمكن تحميله. تواصل مع المشرف.',
  contentTypeLicensePanelTitle: 'رخصة',
  contentTypeDemoButtonLabel: 'عرض المحتوى',
  numResults: ':num results',
  show: 'Show',
  recentlyUsedFirst: 'Recently Used First',
  popularFirst: 'Popular First',
  newestFirst: 'Newest First',
  aToZ: 'A to Z',
  noResultsFound: 'No results found',
  noResultsFoundDesc: 'There is no content type that matches your search criteria.',
  readMore: 'أقرأ أكثر',
  readLess: 'أقرأ أقل',
  contentTypeOwner: 'بواسطة :owner',
  contentTypeUnsupportedApiVersionTitle: 'يتطلب نوع المحتوى هذا إصدارا أساسيا أحدث',
  contentTypeUnsupportedApiVersionContent: 'اتصل بمسؤول النظام لتزويدك بالتحديثات الضرورية',
  contentTypeUpdateAvailable: 'التحديث متاح',
  contentTypeRestricted: 'نوع المحتوى المقيد',
  contentTypeRestrictedDesc: 'تم تقييد استخدام هذا النوع من المحتوى بواسطة مسؤول.',
  contentTypeNotInstalled: 'نوع المحتوى غير مثبت',
  contentTypeNotInstalledDesc: 'ليس لديك إذن لتثبيت أنواع المحتوى.',
  theContentType: 'نوع المحتوى',
  currentMenuSelected: 'الإختيار الحالي',
  errorCommunicatingHubTitle: 'غير قادر على التواصل مع المحور.',
  errorCommunicatingHubContent: 'حدث خطأ. حاول مرة اخرى.',
  warningNoContentTypesInstalled: 'ليس لديك أي أنواع محتوى مثبتة.',
  warningChangeBrowsingToSeeResults: 'انقر <em>All</em> للحصول على قائمة بجميع أنواع المحتويات التي يمكنك تثبيتها.',
  warningUpdateAvailableTitle: 'نسخة جديدة من :contentType متوفرة.',
  warningUpdateAvailableBody: 'تحديث إلى أحدث إصدار لتجربة أكثر جودة',
  licenseDescription: 'وفيما يلي بعض ميزات هذا الترخيص. انقر على رمز المعلومات أعلاه لقراءة نص الترخيص الأصلي.',
  licenseModalTitle: 'تفاصيل الترخيص',
  licenseModalSubtitle: 'حدد ترخيصا لعرض معلومات حول الاستخدام الصحيح',
  licenseUnspecified: 'غير محدد',
  licenseCanUseCommercially: 'يمكن استخدامها تجاريا',
  licenseCanModify: 'يمكن تعديل',
  licenseCanDistribute: 'يمكن التوزيع',
  licenseCanSublicense: 'يمكن ترخيص فرعي',
  licenseCanHoldLiable: 'يمكن أن تحمل المسؤولية',
  licenseCannotHoldLiable: 'لا يمكن تحمل المسؤولية',
  licenseMustIncludeCopyright: 'يجب تضمين حقوق الطبع والنشر',
  licenseMustIncludeLicense: 'يجب أن يتضمن الترخيص',
  licenseFetchDetailsFailed: 'فشل في تحميل تفاصيل الترخيص',
  imageLightboxTitle: 'صور',
  imageLightBoxProgress: ':num من :total',
  nextImage: 'الصورة التالية',
  previousImage: 'الصورة السابقة',
  screenshots: 'لقطات',
  reloadButtonLabel: 'اعادة تحميل',
  videoQuality: 'تصنيف جودة الفيديو',
  videoQualityDescription: 'يساعد هذا التصنيف المستخدم في تحديد الجودة الحالية للفيديو. مثلا 1080p، 720p، HD أو موبايل',
  videoQualityDefaultLabel: 'الجودة :index',
  noContentTypesAvailable: 'No content types are available',
  noContentTypesAvailableDesc: 'Your site is having difficulties connecting to H5P.org and listing the available content types.',
  contentTypeCacheOutdated: 'Content type list outdated',
  contentTypeCacheOutdatedDesc: 'Your site is having difficulties connecting to H5P.org to check for content type updates. You may not be able to update or install new content types.',
  tryAgain: 'Try again',
  getHelp: 'Get help',
  untitled: 'Untitled :libraryTitle',
  title: 'Title',
  metadata: 'Metadata',
  addTitle: 'Add title',
  usedForSearchingReportsAndCopyrightInformation: 'Used for searching, reports and copyright information',
  metadataSharingAndLicensingInfo: 'Metadata (sharing and licensing info)',
  fillInTheFieldsBelow: 'Fill in the fields below',
  saveMetadata: 'Save metadata',
  addAuthor: 'Save author',
  confirmRemoveAuthor: 'Are you sure you would like to remove this author?',
  addNewChange: 'Add new change',
  confirmDeleteChangeLog: 'Are you sure you would like to delete this change log entry?',
  changelogDescription: 'Some licenses require that changes made to the original work, or derivatives are logged and displayed. You may log your changes here for licensing reasons or just to allow yourself and others to keep track of the changes made to this content.',
  logThisChange: 'Log this change',
  newChangeHasBeenLogged: 'New change has been logged',
  loggedChanges: 'Logged changes',
  noChangesHaveBeenLogged: 'No changes have been logged',
  errorHeader: 'An error occured',
  errorCalculatingMaxScore: 'Could not calculate the max score for this content. The max score is assumed to be 0. Contact your administrator if this isn’t correct.',
  maxScoreSemanticsMissing: 'Could not find the expected semantics in the content.',
  copyButton: 'Copy',
  copiedButton: 'Copied',
  pasteButton: 'Paste',
  pasteAndReplaceButton: 'Paste & Replace',
  pasteContent: 'Replace Content',
  confirmPasteContent: 'By doing this you will replace the current content with the content from your clipboard. The current content will be lost. Are you sure you wish to continue?',
  confirmPasteButtonText: 'Replace content',
  copyToClipboard: 'Copy H5P content to the clipboard',
  copiedToClipboard: 'Content is copied to the clipboard',
  pasteFromClipboard: 'Paste H5P content from the clipboard',
  pasteAndReplaceFromClipboard: 'Replace existing content with H5P Content from the clipboard',
  pasteNoContent: 'No H5P content on the clipboard',
  pasteError: 'Cannot paste from clipboard',
  pasteContentNotSupported: 'The content you’re trying to paste is not supported in this context',
  pasteTooOld: 'The content you’re trying to paste is of a lower version (:clip) than what is supported in this context (:local), if possible try to have the content you want to paste upgraded, copy it again and try pasting it here.',
  pasteTooNew: 'The content you’re trying to paste is of a higher version (:clip) than what is supported in this context (:local), if possible try to have this content upgraded first, and then try pasting the content here again.',
  ok: 'OK',
  avTablistLabel: 'Insert using',
  tabTitleBasicFileUpload: 'File Upload',
  tabTitleInputLinkURL: 'Link/URL',
  errorTooHighVersion: 'Parameters contain %used while only %supported or earlier are supported.',
  errorNotSupported: 'Parameters contain %used which is not supported.',
  errorParamsBroken: 'Parameters are broken.',
  libraryMissing: 'Missing required library %lib.',
  scriptMissing: 'Could not load upgrades script for %lib.',
  language: 'Language',
  noLanguagesSupported: 'No languages supported',
  changeLanguage: 'Change language to :language?',
  thisWillPotentially: "This will potentially reset all the text and translations. You can't undo this. The content itself will not be changed. Do you want to proceed?",
  notAllTextsChanged: 'Not all texts were changed, there is only partial coverage for :language.',
  contributeTranslations: 'If you want to complete the translation for :language you can learn about <a href=":url" target="_new">contributing translations to H5P</a>'
};

==> h5p-7.x-1.44.tar.gz: h5p/modules/h5peditor/h5peditor/language/ar.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'جاري التحميل الرجاءالانتظار...',
  selectLibrary: 'حدد المكتبة التي ترغب في استخدامها للمحتوى الخاص بك.',
  unknownFieldPath: 'تعذر العثور على ":path".',
  notImageField: '":path" ليست صورة.',
  notImageOrDimensionsField: '":path" ليست صورة أو أبعاد حقل',
  requiredProperty: 'ال :property مطلوب ويجب أن يكون له قيمة.',
  onlyNumbers: ' :property القيمة يمكن أن تحوي على أرقام فقط.',
  illegalDecimalNumber: ':property can only contain numbers with max :decimals decimals.',
  exceedsMax: ' :property القيمة تتجاوز الحد الأعظمي لـ :max.',
  listExceedsMax: 'تتجاوز القائمة الحد الأقصى لـ :max items.',
  belowMin: ' :property القيمة تحت الحد الأدنى من  :min.',
  listBelowMin: 'القائمة تحتاج على الأقل :min العناصر للمحتوى لتعمل بشكل صحيح',
  outOfStep: ' :property يمكن تغيير قيمة فقط في خطوات من :step.',
  add: 'اضافة',
  addFile: 'اضافة ملف',
  removeFile: 'حذف ملف',
  confirmRemoval: 'هل أنت متأكد أنك تريد حذف :type?',
  removeImage: 'حذف الصورة',
  confirmImageRemoval: 'سيؤدي هذا إلى إزالة الصورة. هل أنت متأكد أنك تريد المتابعة?',
  changeFile: 'تغيير الملف',
  changeLibrary: 'تغيير نوع المحتوى?',
  semanticsError: 'خطأ في الدلالات: :error',
  missingProperty: 'الحقل :index مفقود :property خصائصه.',
  expandCollapse: 'توسيع/طي',
  addEntity: 'اذافة :entity',
  tooLong: 'قيمة الحقل طويلة جداً يجب أن تتضمن :max من الحروف والأرقام',
  invalidFormat: 'تحتوي قيمة الحقل على تنسيق غير صالح أو أحرف غير مسموح بها.',
  confirmChangeLibrary: 'من خلال القيام بذلك سوف تفقد كل العمل المنجز مع نوع المحتوى الحالي. هل تريد بالتأكيد تغيير نوع المحتوى؟',
  commonFields: 'تجاوزات النصوص والترجمة',
  commonFieldsDescription: 'يمكنك هنا تعديل الإعدادات أو ترجمة النصوص المستخدمة في هذا المحتوى.',
  uploading: 'جاري التحميل .. الرجاء الانتظار...',
  noFollow: 'لا يمكن متابعة الحقل ":path".',
  editCopyright: 'تعديل حقوق الطبع والنشر',
  close: 'اغلاق',
  tutorial: 'تعليم',
  editMode: 'نمط التحرير',
  listLabel: 'قائمة',
  uploadError: 'خطأ في تحميل الملف',
  fileToLarge: 'قد يكون الملف الذي تحاول تحميله كبيرا جدا.',
  unknownFileUploadError: 'خطأ في تحميل الملف غير معروف',
  noSemantics: 'حدث خطأ، تعذر تحميل نموذج نوع المحتوى.',
  editImage: 'تعديل الصورة',
  saveLabel: 'حفظ',
  cancelLabel: 'إلغاء',
  resetToOriginalLabel: 'إعادة التعيين إلى النسخة الأصلية',
  loadingImageEditor: 'تحميل محرر الصور، يرجى الانتظار...',
  selectFiletoUpload: 'حدد ملفا لتحميله',
  or: 'أو',
  enterAudioUrl: 'أدخل عنوان مصدر الصوت',
  enterVideoUrl: 'أدخل عنوان مصدر الفيديو أو رابط اليوتيوب',
  enterAudioTitle: 'الصق الرابط أو عنوان مصدر الصوت الاخر',
  enterVideoTitle: 'ألصق رابط اليوتيوب أو عنوان مصدر الفيديو الاخر',
  uploadAudioTitle: 'رفع ملف الصوت',
  uploadVideoTitle: 'رفع ملف الفيديو',
  addVideoDescription: 'النظام يدعم جميع مصادر الفيديو الخارجية بتنسيق MP4 ,webm or ogv ويدعم روابط يوتيوب',
  insert: 'ادراج',
  cancel: 'الغاء',
  height: 'ارتفاع',
  width: 'عرض',
  textField: 'حقل نصي',
  numberField: 'حقل رقمي',
  orderItemUp: 'ترتيب العنصر لأعلى',
  orderItemDown: 'ترتيب العنصر لأدنى',
  removeItem: 'إزالة العنصر',
  hubPanelLabel: 'اختر نوع المحتوى',
  importantInstructions: 'تعليمات هامة',
  showImportantInstructions: 'Show instructions',
  hideImportantInstructions: 'إخفاء التعليمات الهامة',
  hide: 'إخفاء',
  example: 'مثال',
  createContentTabLabel: 'إنشاء محتوى',
  uploadTabLabel: 'رفع',
  uploadPlaceholder: 'لم يتم اختيار ملف',
  uploadInstructionsTitle: 'رفع ملف',
  uploadInstructionsContent: 'يمكن أن تجد أمثلة في <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'رفع ملف',
  uploadFileButtonChangeLabel: 'تغيير الملف',
  uploadingThrobber: 'يتم الرفع الان...',
  uploadSuccess: ':title was successfully uploaded!',
  unableToInterpretError: 'Unable to interpret response.',
  unableToInterpretSolution: 'Please check your error log.',
  h5pFileWrongExtensionTitle: 'تعذر تحميل الملف المحدد',
  h5pFileWrongExtensionContent: 'فقط الملفات بالامتداد .h5p مسموحة.',
  h5pFileValidationFailedTitle: 'تعذر التحقق من الملف.',
  h5pFileValidationFailedContent: 'تأكد أن الملف الذي تم رفعه يحوي على محتوى صالح. H5P يجب تحميل الملفات التي تحتوي على مكتبات فقط من خلال صفحة مكتبات H5P.',
  h5pFileUploadServerErrorTitle: 'الملف لا يمكن تحميله',
  h5pFileUploadServerErrorContent: 'حدث خطأ غير متوقع. تحقق من سجل أخطاء السيرفر  more details.',
  contentTypeSectionAll: 'الكل',
  searchResults: 'Search Results',
  contentTypeSearchFieldPlaceholder: 'البحث عن أنواع المحتوى',
  contentTypeInstallButtonLabel: 'تحميل',
  contentTypeInstallingButtonLabel: 'تحميل',
  contentTypeUseButtonLabel: 'استخدم',
  contentTypeDetailButtonLabel: 'Details',
  contentTypeUpdateButtonLabel: 'تحديث',
  contentTypeUpdatingButtonLabel: 'تحديث',
  contentTypeGetButtonLabel: 'احصل على',
  contentTypeBackButtonLabel: 'العودة',
  contentTypeIconAltText: 'أيقونة',
  contentTypeInstallSuccess: ':contentType تم تحميلها بنجاح!',
  contentTypeUpdateSuccess: ':contentType تم التحديث بنجاح!',
  contentTypeInstallError: ':contentType لا يمكن تحميله. تواصل مع المشرف.',
  contentTypeLicensePanelTitle: 'رخصة',
  contentTypeDemoButtonLabel: 'عرض المحتوى',
  numResults: ':num results',
  show: 'Show',
  recentlyUsedFirst: 'Recently Used First',
  popularFirst: 'Popular First',
  newestFirst: 'Newest First',
  aToZ: 'A to Z',
  noResultsFound: 'No results found',
  noResultsFoundDesc: 'There is no content type that matches your search criteria.',
  readMore: 'أقرأ أكثر',
  readLess: 'أقرأ أقل',
  contentTypeOwner: 'بواسطة :owner',
  contentTypeUnsupportedApiVersionTitle: 'يتطلب نوع المحتوى هذا إصدارا أساسيا أحدث',
  contentTypeUnsupportedApiVersionContent: 'اتصل بمسؤول النظام لتزويدك بالتحديثات الضرورية',
  contentTypeUpdateAvailable: 'التحديث متاح',
  contentTypeRestricted: 'نوع المحتوى المقيد',
  contentTypeRestrictedDesc: 'تم تقييد استخدام هذا النوع من المحتوى بواسطة مسؤول.',
  contentTypeNotInstalled: 'نوع المحتوى غير مثبت',
  contentTypeNotInstalledDesc: 'ليس لديك إذن لتثبيت أنواع المحتوى.',
  theContentType: 'نوع المحتوى',
  currentMenuSelected: 'الإختيار الحالي',
  errorCommunicatingHubTitle: 'غير قادر على التواصل مع المحور.',
  errorCommunicatingHubContent: 'حدث خطأ. حاول مرة اخرى.',
  warningNoContentTypesInstalled: 'ليس لديك أي أنواع محتوى مثبتة.',
  warningChangeBrowsingToSeeResults: 'انقر <em>All</em> للحصول على قائمة بجميع أنواع المحتويات التي يمكنك تثبيتها.',
  warningUpdateAvailableTitle: 'نسخة جديدة من :contentType متوفرة.',
  warningUpdateAvailableBody: 'تحديث إلى أحدث إصدار لتجربة أكثر جودة',
  licenseDescription: 'وفيما يلي بعض ميزات هذا الترخيص. انقر على رمز المعلومات أعلاه لقراءة نص الترخيص الأصلي.',
  licenseModalTitle: 'تفاصيل الترخيص',
  licenseModalSubtitle: 'حدد ترخيصا لعرض معلومات حول الاستخدام الصحيح',
  licenseUnspecified: 'غير محدد',
  licenseCanUseCommercially: 'يمكن استخدامها تجاريا',
  licenseCanModify: 'يمكن تعديل',
  licenseCanDistribute: 'يمكن التوزيع',
  licenseCanSublicense: 'يمكن ترخيص فرعي',
  licenseCanHoldLiable: 'يمكن أن تحمل المسؤولية',
  licenseCannotHoldLiable: 'لا يمكن تحمل المسؤولية',
  licenseMustIncludeCopyright: 'يجب تضمين حقوق الطبع والنشر',
  licenseMustIncludeLicense: 'يجب أن يتضمن الترخيص',
  licenseFetchDetailsFailed: 'فشل في تحميل تفاصيل الترخيص',
  imageLightboxTitle: 'صور',
  imageLightBoxProgress: ':num من :total',
  nextImage: 'الصورة التالية',
  previousImage: 'الصورة السابقة',
  screenshots: 'لقطات',
  reloadButtonLabel: 'اعادة تحميل',
  videoQuality: 'تصنيف جودة الفيديو',
  videoQualityDescription: 'يساعد هذا التصنيف المستخدم في تحديد الجودة الحالية للفيديو. مثلا 1080p، 720p، HD أو موبايل',
  videoQualityDefaultLabel: 'الجودة :index',
  noContentTypesAvailable: 'No content types are available',
  noContentTypesAvailableDesc: 'Your site is having difficulties connecting to H5P.org and listing the available content types.',
  contentTypeCacheOutdated: 'Content type list outdated',
  contentTypeCacheOutdatedDesc: 'Your site is having difficulties connecting to H5P.org to check for content type updates. You may not be able to update or install new content types.',
  tryAgain: 'Try again',
  getHelp: 'Get help',
  untitled: 'Untitled :libraryTitle',
  title: 'Title',
  metadata: 'Metadata',
  addTitle: 'Add title',
  usedForSearchingReportsAndCopyrightInformation: 'Used for searching, reports and copyright information',
  metadataSharingAndLicensingInfo: 'Metadata (sharing and licensing info)',
  fillInTheFieldsBelow: 'Fill in the fields below',
  saveMetadata: 'Save metadata',
  addAuthor: 'Save author',
  confirmRemoveAuthor: 'Are you sure you would like to remove this author?',
  addNewChange: 'Add new change',
  confirmDeleteChangeLog: 'Are you sure you would like to delete this change log entry?',
  changelogDescription: 'Some licenses require that changes made to the original work, or derivatives are logged and displayed. You may log your changes here for licensing reasons or just to allow yourself and others to keep track of the changes made to this content.',
  logThisChange: 'Log this change',
  newChangeHasBeenLogged: 'New change has been logged',
  loggedChanges: 'Logged changes',
  noChangesHaveBeenLogged: 'No changes have been logged',
  errorHeader: 'An error occured',
  errorCalculatingMaxScore: 'Could not calculate the max score for this content. The max score is assumed to be 0. Contact your administrator if this isn’t correct.',
  maxScoreSemanticsMissing: 'Could not find the expected semantics in the content.',
  copyButton: 'Copy',
  copiedButton: 'Copied',
  pasteButton: 'Paste',
  pasteAndReplaceButton: 'Paste & Replace',
  pasteContent: 'Replace Content',
  confirmPasteContent: 'By doing this you will replace the current content with the content from your clipboard. The current content will be lost. Are you sure you wish to continue?',
  confirmPasteButtonText: 'Replace content',
  copyToClipboard: 'Copy H5P content to the clipboard',
  copiedToClipboard: 'Content is copied to the clipboard',
  pasteFromClipboard: 'Paste H5P content from the clipboard',
  pasteAndReplaceFromClipboard: 'Replace existing content with H5P Content from the clipboard',
  pasteNoContent: 'No H5P content on the clipboard',
  pasteError: 'Cannot paste from clipboard',
  pasteContentNotSupported: 'The content you’re trying to paste is not supported in this context',
  pasteTooOld: 'The content you’re trying to paste is of a lower version (:clip) than what is supported in this context (:local), if possible try to have the content you want to paste upgraded, copy it again and try pasting it here.',
  pasteTooNew: 'The content you’re trying to paste is of a higher version (:clip) than what is supported in this context (:local), if possible try to have this content upgraded first, and then try pasting the content here again.',
  ok: 'OK',
  avTablistLabel: 'Insert using',
  tabTitleBasicFileUpload: 'File Upload',
  tabTitleInputLinkURL: 'Link/URL',
  errorTooHighVersion: 'Parameters contain %used while only %supported or earlier are supported.',
  errorNotSupported: 'Parameters contain %used which is not supported.',
  errorParamsBroken: 'Parameters are broken.',
  libraryMissing: 'Missing required library %lib.',
  scriptMissing: 'Could not load upgrades script for %lib.',
  language: 'Language',
  noLanguagesSupported: 'No languages supported',
  changeLanguage: 'Change language to :language?',
  thisWillPotentially: "This will potentially reset all the text and translations. You can't undo this. The content itself will not be changed. Do you want to proceed?",
  notAllTextsChanged: 'Not all texts were changed, there is only partial coverage for :language.',
  contributeTranslations: 'If you want to complete the translation for :language you can learn about <a href=":url" target="_new">contributing translations to H5P</a>',
  unknownLibrary: 'Unfortunately, the selected content type \'%lib\' isn\'t installed on this system.',
  proceedButtonLabel: 'Proceed to save',
  enterFullscreenButtonLabel: 'Enter fullscreen',
  exitFullscreenButtonLabel: 'Exit fullscreen'
};
